package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````$A,``#0```#DD````````#0`(``(
M`"@`%P`6``8````T````-````#0``````0````$```4````$`````P```#0!
M```T`0``-`$``!<````7````!`````$````!````````````````````((8`
M`""&```%`````!````$```#\C0``_)T``/R=```H`@``>!(```8`````$```
M`@```!".```0G@``$)X``+@```"X````!@````0```!0Y71DC'@``(QX``",
M>```W````-P````$````!````%'E=&0```````````````````````````8`
M```0````4N5T9/R-``#\G0``_)T```0"```$`@``!`````$````O;&EB+VQD
M+6UU<VPM:3,X-BYS;RXQ```1````3`````0````'`````($``)M$!$E(CA`A
MBH0$R`````!,````4````%0```!5````6@```%L```!<`````````%X`````
M`````````%\```!@````80``````````````:G^:?.K3[P[.WD<M;\7?'R[%
MF[:XC?$.U&34?"'_Y`[9<5@<^J%L8,+E/RRR`8MOXD?&`;OCDGQ5PSS29Z_,
M9H@'<--#1=7L,V+;[7^IG)OAIP(*H^#[20`````````````````````,````
M```````````2````R0$`````````````$@```!0``````````````!$```#O
M`0`````````````1````:P$`````````````$@```!L``````````````!(`
M``"H`0`````````````2````(P``````````````$@```"H`````````````
M`!(```#\`0`````````````2````M`$`````````````$@```$(#````````
M`````"$````S```````````````2````.0``````````````$@```$``````
M`````````!(````(`P`````````````2````^0(`````````````$@```($"
M`````````````!(```!'```````````````2````(@(`````````````$@``
M`$X``````````````!(```"V`@`````````````2````50``````````````
M$@```%T``````````````"````!Q```````````````2````GP(`````````
M````$@```'D``````````````!(```!_```````````````2````B```````
M````````(````/("`````````````!(```"D```````````````2````J0``
M````````````$@````T"`````````````!$```"]`@`````````````2````
M3P(`````````````$@```!@#`````````````!(```"P```````````````@
M````00(`````````````$@```*T#`````````````!(```#(`@``````````
M```1````00,`````````````$0```',"`````````````!(````N`P``````
M```````2````0P,`````````````$0```,X``````````````!(````F`P``
M```````````2````>0$`````````````$@```-<``````````````"(```#F
M```````````````2````Z@(`````````````$@```%\"`````````````!(`
M``#K```````````````2````\0``````````````(````*H"````````````
M`!(````+`0`````````````2````F0$`````````````$@```!`!````````
M`````"`````L`0`````````````2````CP(`````````````$@```(@!````
M`````````!(````R`0`````````````2````0P$`````````````$@```!T"
M`````````````!(```!Z```````````````2````+@(`````````````$@``
M`&@"`````````````!(````?`P`````````````2````20$`````````````
M$@```!`#`````````````!(```!=`0`````````````2````&`(`````````
M````$@```-<!`````````````!(```!+`P`````````````2````0`,`````
M````````(0```&0!`````````````!(````[`P``.!$``-H!```2``D`Z0$`
M`&`Y```!````$@`*`.\#```D+```G`D``!(`"0!E!```OC@``%X````2``D`
MS`,``/HF```%````$@`)`/X#```L#P```0```!(`!@`2!```P#4``/X"```2
M``D`6`0``/\F``#:`0``$@`)`&,#```DH````````!``%`#=`P``>RL``*D`
M```2``D`_`,``(<E```[````$@`)``0$```!*P``2P```!(`"0`R!```V2@`
M`!D````2``D`;P,``'2P````````$``4`)(#```M$P``,@```!(`"0`_!```
M\B@``+$````2``D`*`0``""@```$````$0`3`%P#```DH````````!``$P!H
M`P``$A,````````0``D`FP,``$PK```O````$@`)`+8#```5)@``Y0```!(`
M"0!+!```HRD``%X!```2``D``&QI8G!E<FPN<V\`;W!E;F1I<@!S=&1E<G(`
M<F5A;&QO8P!A8V-E<W,`<VYP<FEN=&8`;'-E96L`9V5T<&ED`'-T<F-M<`!M
M96US970`=6YL:6YK`&UE;6UO=F4`7TIV7U)E9VES=&5R0VQA<W-E<P!S=')N
M8VUP`&QS=&%T`&-L;W-E9&ER`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L
M90!O<&5N`'-T<G-T<@!?7V1E<F5G:7-T97)?9G)A;65?:6YF;U]B87-E<P!R
M96%D;&EN:P!?7V-X85]F:6YA;&EZ90!E>&ET`&-L;W-E`%])5$U?<F5G:7-T
M97)434-L;VYE5&%B;&4`<F5A9`!?7W)E9VES=&5R7V9R86UE7VEN9F]?8F%S
M97,`<FUD:7(`7U]E<G)N;U]L;V-A=&EO;@!M:V1I<@!P=&AR96%D7V=E='-P
M96-I9FEC`&UE;6-P>0!G971U:60`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I
M;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T
M7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S
M=E\R<'9?9FQA9W,`7V9I;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA
M9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O
M<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?
M<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O
M;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P
M97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F,N;75S;"UX.#8N<V\N,0!F
M<')I;G1F`'-T<F1U<`!P=&AR96%D7V%T9F]R:P!R96%D9&ER`'-P<FEN=&8`
M<W1R8VAR`'-T<G1O:P!S=')N8W!Y`%]?;&EB8U]S=&%R=%]M86EN`%]?7V5N
M=FER;VX`7U]S=&%C:U]C:&M?9F%I;`!?961A=&$`7U]B<W-?<W1A<G0`7V5N
M9``O=7-R+VQI8B]P97)L-2]C;W)E7W!E<FPO0T]210!?<W1A<G1?8P!G971?
M=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`
M<&%R7V-U<G)E;G1?97AE8P!P87)?<V5T=7!?;&EB<&%T:`!P87)?;6MT;7!D
M:7(`>'-?:6YI=`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0D]/
M5`!M>5]P87)?<&P`<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A<E]I;FET
M7V5N=@!P87)?9FEN9'!R;V<`<&%R7V-L96%N=7``````W)X```@```#\G@``
M"````$R?```(`````*````@````$H```"`````B@```(````#*````@````0
MH```"````!2@```(````(*````@```#4G@``!@$``-B>```&`@``X)X```8#
M``#DG@``!@0``.B>```&!0``[)X```8&``#PG@``!@<``/2>```&"```^)X`
M``8)````GP``!@H```2?```&"P``")\```8-```,GP``!@X``!"?```&#P``
M%)\```80```8GP``!A$``!R?```&$@``()\```83```DGP``!A0``"B?```&
M%0``+)\```86```PGP``!A<``#2?```&&```.)\```89```\GP``!AH``$"?
M```&&P``1)\```8<``!(GP``!AT``%"?```&'@``5)\```8?``!8GP``!B``
M`%R?```&(0``8)\```8B``!DGP``!B,``&B?```&)```;)\```8E``!PGP``
M!B8``'2?```&)P``>)\```8H``!\GP``!BH``("?```&*P``A)\```8L``"(
MGP``!BT``(R?```&+@``D)\```8O``"4GP``!C```)B?```&,0``G)\```8R
M``"@GP``!C,``*2?```&-```J)\```8U``"LGP``!C8``+"?```&-P``M)\`
M``8X``"XGP``!CD``+R?```&.@``P)\```8[``#$GP``!CP``,B?```&/0``
MS)\```8^``#0GP``!C\``-2?```&0```V)\```9!``#<GP``!D(``."?```&
M0P``Y)\```9$``#HGP``!D4``.R?```&1@``\)\```9'``#TGP``!D@``/B?
M```&20``_)\```9+``"#[`SH.04``.@`*@``@\0,PP```/^S!````/^C"```
M``````#_HPP```!FD/^C$````&:0_Z,@````9I#_HR0```!FD/^C*````&:0
M_Z,L````9I#_HS````!FD/^C.````&:0_Z,\````9I#_HT````!FD/^C1```
M`&:0_Z-(````9I#_HTP```!FD/^C4````&:0_Z-4````9I#_HU@```!FD/^C
M7````&:0_Z-@````9I#_HV0```!FD/^C:````&:0_Z-P````9I#_HW0```!F
MD/^C>````&:0_Z-\````9I#_HX@```!FD/^CC````&:0_Z.0````9I#_HY@`
M``!FD/^CG````&:0_Z.@````9I#_HZ0```!FD/^CJ````&:0_Z.L````9I#_
MH[0```!FD/^CN````&:0_Z/`````9I#_H\0```!FD/^CR````&:0_Z/,````
M9I#_H]````!FD/^CU````&:0_Z/8````9I#_H]P```!FD/^CY````&:0_Z/H
M````9I#_H^P```!FD/^C\````&:0_Z/T````9I#_HP`!``!FD/^C!`$``&:0
M_Z,(`0``9I#_HPP!``!FD/^C%`$``&:0_Z,8`0``9I#_HQP!``!FD/^C(`$`
M`&:0_Z,D`0``9I#_HR@!``!FD/^C+`$``&:0_Z,P`0``9I#_HS0!``!FD(U,
M)`2#Y/#_<?Q5C4$(B>575E-1B<[H#`(``('#=8T``(/L#%"-00104>@1____
MBX,0`0``@\0,4%#_L_P```#H._[__XN#'````(/$$(N[E````(`X`'4TZ)+^
M__^%P(F#J!$``'4*@^P,:@'HWO[__X/L#%#H!?___UG_-^A%____@\00QH!1
M!0```(/L#/\WZ#'___^`B.H"```"6O\WZ"+___^`B.H"```!BP:#Q!"#P`4]
M____/W844%"-@^N:____L[````!0Z(C]__^#[`S!X`)0Z)3^__^+?@2)@YP1
M``"#Q!#'@Z`1```$````N0$```"+%XD0C9-7G?__B5`$BY-8`0``B5`(C9-:
MG?__B5`,BQ8YT7T*BS2/B72(#$'K\H/L#,=$D`P`````@\(#:@!0C8/ZAO__
M4E#_LZ@1``#H=OW__X/$((7`B<9U$X/L#/^SJ!$``.C__?__@\00B<:#[`S_
MLZ@1``#HK/W__XV#.9O__^B1#@``@\00A<!U,(.[I!$```!U$8V#[IK__^AV
M#@``B8.D$0``BX.D$0``A<!T#(/L#%#HTR4``(/$$(/L#/^SJ!$``.@<_O__
MZ%_\__^#Q!"-9?")\%E;7E]=C6'\PS'MB>"#Y/!04.@`````@00D\(H``%#H
M`````%/H+````('#E8L``(/L$(M$)!AJ`/^S-````/^SA````(U0!%+_,/^S
M%````.@!_?__BQPDP^AJ`0``!6"+``"-B%P!``"-D%\!```IRH/Z!G87BX"`
M````A<!T#56)Y8/L%%'_T(/$$,G#5>@X`0``@<$JBP``B>564XV!7`$``(V9
M7`$``+X"````*=C!^`*9]_Z%P'03BY'@````A=)T"5%14%/_TH/$$(UE^%M>
M7<-5B>575E/H=?___X'#WHH``(/L#("[>`$```!U:8.[S`````!T$8/L#/^S
M.`$``.AM_/__@\00C;,\____C;M`____*??!_P)/BX-\`0``.<=V#$")@WP!
M``#_%(;KZN@@____@[ND`````'02C8/PVO__@^P,4.CE^___@\00QH-X`0``
M`8UE]%M>7UW#5>@`````6H'"58H``(GE4U#HW/[__X'#18H``(.[\`````!T
M&8V#@`$``%)J`%"-@_#:__]0Z!C\__^#Q!"-DT3___^#.@!T$XN#;````(7`
M=`F#[`Q2_]"#Q!"+7?S)Z<;^__^+!"3#BPPDPU57,=)64X'L?`$``(E$)`AE
MH10```")A"1L`0``,<"+1"0(C5@<BPR3C40D+`_)B0R00H/Z$'7NC8PD+`$`
M`(M0-#-0((/`!#-0!#-0_-'"B5`\.<AUZ(M$)`B+`(E$)!"+1"0(BU0D$(M`
M!,'*`HE$)!B+1"0(BTPD&(M`",')`HE$)`R+1"0(BWPD#(ML)`R+0`PQSR-\
M)!`S?"0,B40D%(M$)`B+7"04BT`0B40D'(M$)"R+="0<C;0&F7F"6HM$)!#!
MP`4!\(MT)`PS="04(W0D&#-T)!0!QHM$)#"-A`.9>8):B<LQTP''B?`A\\'`
M!3'+P<X"`<>+1"0TC80%F7F"6HML)#@!PXGXP<`%C8PIF7F"6HML)#P!PXG0
M,?`A^,'/`C'0C90JF7F"6HML)$`!R(G9P<$%`<B)\3'Y(=DQ\8VT+IEY@EJ+
M;"1$`=&)PL'"!<'+`@'1B?HQVB'"P<@",?J-O"^9>8):BVPD2`'RB<[!Q@4!
M\HG&B=@Q\"'(,=B-G"N9>8):BVPD3`'XB=?!QP4!^(G/B?'!SP(Q^2'1,?&-
MM"Z9>8):BVPD4`'9B</!PP4!V8G3B?K!RP(QVB'"P<@",?J-O"^9>8):BVPD
M5`'RB<[!Q@4!\HG&B=@Q\"'(,=B-G"N9>8):BVPD6`'XB=?!QP4!^(G/B?'!
MSP(Q^2'1,?&-M"Z9>8):BVPD7`'9B</!PP4!V8G3B?K!RP(QVB'"P<@",?J-
MO"^9>8):BVPD8`'RB<[!Q@4!\HG&B=@Q\"'(,=B-G"N9>8):BVPD9`'XB=?!
MQP4!^(G/B?'!SP(Q^2'1,?&-M"Z9>8):`=F)P\'#!0'9B=.)^L'+`C':(<+!
MR`(Q^HG%B=@!\HG.,>C!Q@4AR,')`@'RBW0D:#'8C;0WF7F"6HGO,<\!\(G6
M(=?!Q@4Q[\'*`@'PBW0D;(V<,YEY@EJ)SC'6`=^)PR'&P<,%,<[!R`(!WXM<
M)'"-G!V9>8):BVPD=`'>B?O!PP6-C"F9>8):BVPD>`'>B=,QPR'[,=/!SP*-
ME"J9>8):`<N)\<'!!0'+B<$Q^2'QP<X",<$!T8G:P<(%`=&+5"1\C800H>O9
M;HGZ,?(QVL'+`@'"B<C!P`4!PHN$)(````"-O`>AZ]ENB?`QV#'(`?B)U\''
M!0'XB<^+C"2$````P<\"C;0.H>O9;HG9,?DQT0'QB<;!Q@4!\8G6BY0DB```
M`,'.`HV<$Z'KV6Z)^C'R,<(!VHG+P<@"P<,%`=J)PXN$)(P```"-O`>AZ]EN
MB?`QV#'(`?B)U\''!0'XB<^+C"20````P<\"C;0.H>O9;HG9,?DQT0'QB<;!
MQ@4!\8G6BY0DE````,'.`HV<$Z'KV6Z)^C'R,<+!R`(!VHG+P<,%`=J)PXN$
M))@```"-O`>AZ]ENB?`QV#'(`?B)U\''!0'XB<^+C"2<````P<\"C;0.H>O9
M;HG9,?DQT0'QB<;!Q@4!\8G6BY0DH````,'.`HV<$Z'KV6Z)^C'R,<+!R`(!
MVHG+P<,%`=J)PXN$)*0```"-O`>AZ]ENB?`QV#'(`?B)U\''!0'XB<^+C"2H
M````P<\"C;0.H>O9;HG9,?DQT0'QB<;!Q@4!\8G6BY0DK````,'.`HV<$Z'K
MV6Z)^C'R,<+!R`(!VHG+P<,%`=J)PXN$)+````"-O`>AZ]ENB?`QV#'(`?B)
MU\''!0'XB<^+C"2T````P<\"C;0.H>O9;HG9,?DQT0'QB<;!Q@4!\8G6BY0D
MN````,'.`HV<$Z'KV6Z)^C'R,<+!R`(!VHG+P<,%`=J)PXN$)+P```"-O`>A
MZ]ENB?`QV#'(`?B)U\''!0'XB<^+C"3`````P<\"C;0.H>O9;HG9,?DQT0'Q
MB<;!Q@4!\8G6BY0DQ````,'.`HV<$Z'KV6Z)^C'R,<+!R`*)Q8N$),@````!
MVHG+P<,%`=J-G`>AZ]ENB?`QZ#'(`=B)T\')`L'#!0'8B>L)RXG?B>LAUR'+
MP<H""?N+O"3,````C;0^W+P;CXG/"=<!\XG&P<8%`?.)_HG/(<8AU\'(`@GW
MB[0DT````(VT-=R\&X\!]XG>P<8%`?>)U@G&(=[!RP*)]8G6(<8)[HNL)-0`
M``"-C"G<O!N/B=V)PPGK`<Z)^2'[P<$%`<Z)V8G#(>L)RXN,)-@```"-E`K<
MO!N/B>D!T\'/`HGR"?G!P@4A\0'3P<X"B<J)Z2'Y"=&+E"3<````C800W+P;
MCXGZ"?(!P8G8P<`%`<&)T(GZ(=@A\L'+`@G"BX0DX````(V$!=R\&X\!PHG(
MP<`%`<*)\`G8(<B)Q8GP(=@)Z(NL).0```"-O"_<O!N/`?B)U\''!0'XB<^)
MV<'/`@GY(=&)S8G9(?D)Z8NL).@```"-M"[<O!N/`?&)QL'&!0'QB=:)^L'.
M`@GR(<+!R`*)U8GZ(?()ZHNL).P```"-G"O<O!N/`=J)R\'#!0':B<.)\`G8
M(<B)Q8GP(=@)Z(NL)/````"-O"_<O!N/`?B)U\''!0'XB<^)V<'/`@GY(=&)
MS8G9(?D)Z8NL)/0```"-M"[<O!N/`?&)QL'&!0'QB=:)^L'.`@GR(<*)U8GZ
M(?()ZHNL)/@```"-G"O<O!N/`=J)R\'(`L'#!0':B<.)\`G8(<B)Q8GP(=@)
MZ(NL)/P```"-O"_<O!N/`?B)U\''!0'XB<^)V<'/`@GY(=&)S8G9(?D)Z8NL
M)``!``"-M"[<O!N/`?&)QL'&!0'QB=:)^L'.`@GR(<+!R`*)U8GZ(?()ZHNL
M)`0!``"-G"O<O!N/B<6)\`GH`=J)RR'(P<,%`=J)PXGP(>@)V(N<)`@!``"-
MG!_<O!N/`=B)T\')`L'#!0'8B>L)RXG?B>LAUR'+P<H""?N+O"0,`0``C;0^
MW+P;CP'SB<;!Q@4!\XG."=:)]XG.(<<AUL'(`@G^B[PD$`$``(V\/=R\&X\!
M_HG?P<<%`?Z)UPG'(=_!RP*)_8G7(<<)[XNL)!0!``"-C"G<O!N/`?F)]\''
M!0'YB<<)WR'WB?V)QR'?">^+K"08`0``C90JW+P;CP'7B<K!S@+!P@4!UXN4
M)!P!``"-E!#6P6+*B=@Q\#'(P<D"`=")^L'"!0'0BY0D(`$``(V<$];!8LJ)
M\C'*,?K!SP(!VHG#P<,%`=J+G"0D`0``C;0>UL%BRHG+,?LQP\'(`@'SB=;!
MQ@4!\XG&BX0D*`$``(V,`=;!8LJ)^#'P,=`!R(G9P<$%`<B)T8N4)"P!``#!
MR0*-E!?6P6+*B?<QSS'?`=>)PL'"!0'7BY0D,`$``,'+`HVT%M;!8LJ)RC':
M,<+!R`(!\HG^P<8%`?*)QHN$)#0!``"-A`'6P6+*B=DQ\3'YP<\"`<&)T,'`
M!0'!BX0D.`$``(V<`];!8LJ)\#'X,=`!V(G+P<,%`=B)TXN4)#P!``#!RP*+
M;"00C906UL%BRHG^,=XQSL')`@'6B<+!P@4!UHN4)$`!``"-O!?6P6+*B=HQ
MRC'"P<@"`?J)]\''!0'ZB<>+A"1$`0``C80#UL%BRHG+,?LQ\\'.`@'#B=#!
MP`4!PXN$)$@!``"-C`'6P6+*B?@Q\#'0`<B)V<'!!0'(B=&+E"1,`0``P<D"
MC907UL%BRHGW,<\QW\'+`@'7B<+!P@4!UXN4)%`!``"-M!;6P6+*B<HQVC'"
MP<@"`?*)_L'&!0'RB<:+A"14`0``C80!UL%BRHG9,?$Q^<'/`@'!B=#!P`4!
MP8N$)%@!``"-G`/6P6+*B?`Q^#'0`=B)R\'#!0'8B=.+E"1<`0``P<L"C906
MUL%BRHG^,=XQSL')`@'6B<+!P@4!UHN4)&`!``"-O!?6P6+*B=HQRC'"P<@"
M`?J)]\''!0'ZB[PD9`$``(V\.];!8LJ)RS'#,?/!S@(!^XG7P<<%`?N+O"1H
M`0``C;P]UL%BR@'/B<$Q\0-T)!0QT<'*`@-4)`P!^8G?`UPD&,''!0'Y`T0D
M'(M\)`B)#XE?!(E'$(E7"(N$)&P!``!E,P44````B7<,=`7H<Q@``('$?`$`
M`%M>7UW#55=64S'VZ)SR__^!PP5^``"#[!R%P'1NBXN\````B<6+,8ET)`0Q
M]H-\)`0`=%>*30"$R70(@/D]=`-%Z_&+?"0$B<$IQ8LWA?9T.HE4)`Q055&)
M3"045NC;[O__@\00A<"+3"0(BU0D#'45@#PN/74/*WPD!(UT+@'!_P*).NL%
M@\<$Z\"#Q!R)\%M>7UW#@^P<C50D"&6+#10```")3"0,,<GH5____XM,)`QE
M,PT4````=`7HK1<``(/$',-75NB>%P``@<)*?0``4XG#@^P0B[J\````9:$4
M````B40D##'`C70D"(GRB=CH#____X7`=!>+!XM4)`B-!)"+4`2%THD0=.&#
MP`3K\HM$)`QE,P44````=`7H2A<``(/$$%M>7\-55U93@^PL_.AU\?__@</>
M?```B00DB50D!&6A%````(E$)!PQP#'`@#H]C50D&`^4P`%$)`2#S?^+?"0$
M,?:)Z8GP\J[WT8U!_XE$)`B+!"3HA?[__X7`=#&)Z8G'B<*)\/*NB<WWU4TY
M;"0(#X>L````,<"+7"0$B@P#B`P"0(3)=?$QP.D0`0``BX.\````,>V+$(,\
MJ@!T`T7K]X.[F!$```"-=0)T(\'F`E%15E+HU>S__XN3O````(/$$(7`B0)U
M1H/(_^G.````B50D#,'F`H/L#%;'@Y@1```!````Z!SM__^#Q!"%P(G'=-6#
M[@A05HM4)!125^@+[?__BX.\````@\00B3B+@[P```"+`,=$J`0`````B6PD
M&(L$)(H0A-)T"(#Z/70#0.ORB[.\````BTPD&(/L#"M$)`R+%HT\BHM,)!2-
M1`$"4.BO[/__@\00A<")!P^$9/___XL&BU0D&(L$D/\$)(LT)(I6_X32B!!T
M"(#Z/70#0.OIQ@`],=*+?"0$B@P7B$P0`4*$R77PZ>G^__^+7"0<93,=%```
M`'0%Z)85``"#Q"Q;7E]=PU575E.![(P```#\Z+WO__^!PR9[``")QF6A%```
M`(E$)'PQP(7V#X08`0``@#X`#X0/`0``@^P,5NB`Z___@\00A<")Q0^$^0``
M`(V#I9K__XE$)`B-@Z2:__^)1"0,@^P,5>BVZ___@\00A<`/A+T```"#P!.)
M!"124O]T)!#_="0,Z([K__^#Q!"%P'304%#_="04_W0D#.AXZ___@\00A<!T
MNH/*_S'`B?>)T8/L#/*NBWPD#/?1B4PD$(G1BU0D$/*NB<CWT(T,`E'H?.O_
M_XG'C8.GFO___W0D$%905^B0[/__@\08C40D)%!7Z&+L__^#Q!!`=!F+1"0L
M)0#P```]`$```'4)B?CH[_[__^L,@^P,5^@JZ___@\00@^P,5^@F[/__@\00
MZ2____^#[`Q5Z#WK__^)-"3H]>O__X/$$(M$)'QE,P44````=`7H.!0``('$
MC````%M>7UW#5U:)QE/H8N[__X'#RWD``(/L#(N[E````/\WZ.WK__]:604H
M`0``4%;HW^K__X/$$(7`=`0QP.M7@^P,_S?HRNO__XN`.`$``(/$$"4`\```
M/0!```!U%U!0:@)6Z"/J__^#Q!"%P`^4P`^VP.LA@^P,_S?HE.O__XN`.`$`
M`(/$$"4`\```/0"@``!UI^O(6UY?PU/HTNW__X'#.WD``(/L%(N#E````/\P
MZ%WK__^-D[C9__]2C9.MFO___[/X````4E#H,^O__X/$*%O#5E/HENW__X'#
M_W@``(/L$(NSE````/\VZ"'K__^)!"3HH/___UC_-N@1Z___6HV35IW__UEJ
M`%)2C9/XEO__4HV3R9K__U)0Z'GI__^#Q"1;7L-55U93Z$'M__^!PZIX``"!
M[!P@``!EH10```")A"0,(```,<#H8NG__XV3WIK__X/L#%)0C8/BFO__4&@!
M$```C70D)E;H(>G__XU0`8/$(('Z`1```'8"#PN%P'D$,?;K85)H`!```(VL
M)!,0``!55NC=Z?__@\00A<")QWC?C4`!@^P,4.A`Z?__@\00A<")QG3*.>AS
M!XT$.#G%<KDY[G8(C40]`#G&<JV!_P$0``!_I5!755;H/^K__\8$/@"#Q!"+
MC"0,(```93,-%````(GP=`7H,1(``('$'"```%M>7UW#Z1;___]55U93@>PL
M$```_.A0[/__@<.Y=P``BY0D1!```(NT)$`0``!EH10```")A"0<$```,<"-
M@^Z:__^)%"3H"/K__XG%4%!J+U;H[.C__X/$$(7`BQ0D=!*-@_>:__^)\NAZ
M^O__Z4\!```QP(/)_XGW\J[WT8U!_XE$)`104(V#!)O__U!2Z&_I__^)PHV#
MI9K__X/$$(E$)`B+@Y0```")!"2%TG2Q@#H`=02+5"0(A>UT'%=74HE4)!A5
MZ.GG__^#Q!"%P(M4)`P/A,\````QP(/)_XG7\J[WT4F`?`K_+W4'2<8$"@#K
M\HM$)`2-1`$!/?\/```/CUO___^-@P:;__]14590C8/SF___4E!H`!```(U\
M)#A7Z&3G__]`@\0@/0`0``!V`@\+@^P,BT0D#/\PZ,GH__]96@4H`0``4%?H
MH^C__X/$$(7`=5&#[`R+1"0,_S#HINC__XN`.`$``(/$$"4`\```/0"```!U
M+E)2:@%7Z/_F__^#Q!"%P'4=C8/WFO__B?KH4/G__X/L#%?H>N?__X/$$(G&
MZQI04(V#!)O__U!J`.A+Z/__@\00B<+IZO[__XGPB[0D'!```&4S-10```!T
M!>A2$```@<0L$```6UY?7<.+1"0$C5`!BDK_A,ET"H#Y+W4"B=!"Z^_#55=6
M4X/L#/R+="0@Z%SJ__^!P\5U``"%]G0VBA:$TG0P,<"#R?^)]_*N]]&-1`[^
M.<9S%(`X+W4(2.OT2#G&<P>`."]U]NLM.<9U*8#Z+W4+@^P,C8.EFO__ZPF-
M@P:;__^#[`Q0Z+/F__^#Q!#K.8`X+W4%2#G&<O8I\(U0`H'Z`!```'<@0#T`
M$```=@(/"U)05HVSF`$``%;HWN;__X/$$(GPZP(QP(/$#%M>7UW#5U93@^PP
M_.BPZ?__@<,9=0``9:$4````B40D+#'`C8,(F___C7PD"HVSE-G__[DB````
M\Z3HFO?__XV#$9O__^B/]___C8,9F___Z(3W__^-@R*;___H>??__XV#*9O_
M_^AN]___C8,YF___Z&/W__^-@^Z:___H6/?__XV#19O__^A-]___C8-/F___
MZ$+W__^-@UF;___H-_?__XV#]YK__^@L]___C8-CF___Z/+V__^%P'0-B<*-
M@T^;___H=O?__XV#=)O__^C6]O__A<!T#8G"C8.&F___Z%KW__^-@Y&;___H
MNO;__X7`=`J)PHV#[IK__^LVC8.AF___Z*'V__^%P(G"=1^-1"0;4HV3LIO_
M_VH*4E#H+^7__X/$$(7`=0^-5"0EC8-%F___Z`;W__^-D_.<__^-@RF;___H
M]?;__XM$)"QE,P44````=`7H)@X``(/$,%M>7\-3Z%CH__^!P\%S``"#[`B#
MNU0!``#_=2B-@T6;___H)/;__S'2A<!T#HH`A,`/E<(\,`^5P"'"#[;2B9-4
M`0``BX-4`0``@\0(6\-3Z`WH__^!PW9S``"#[`CHT.7__X/L#%#HY^3__X/$
M$#'2A<!T`HL0@\0(B=!;PU575E.#[!S\Z-?G__^!PT!S``"+="0PC8.]F___
MZ*OU__^%P'0'@#@`B<5U#8GRC8.]F___@\0<ZUY04%95Z&+D__^#Q!"%P'57
M@\K_B?>#[`R)T?*NB>_WT8E,)!B)T8M4)!CRKHG(]]"-#`)1Z/+C__^)QXV#
M!)O__XDL)%"-@_.;__]64%?H`.7__XV#O9O__XGZ@\0\6UY?7>G!]?__@\0<
M6UY?7<-55U93@>P,@0``_.@KY___@<.4<@``9:$4````B80D_(```#'`C8/4
MF___BZPD(($``,=$)#0`````C7PD1(VS/`$``+D&````B40D+(V#I9K__\=$
M)$``````\Z6)1"0PC8/9F___B40D.(V#WIO__XE$)#R-@^Z:___HI/3__X7`
M="&`.`")QG0:@^P,4.C#_O__B30DZ%#C__^)1"04Z9T#``#H?O[__X7`B<:-
M?"0X=3.+!X7`="?H9?3__S'VA<!T$X`X`'0.@^P,4.@9X___@\00B<:#QP2%
M]G35ZP:-L\V;__\QP(GW@\G_\JZ#[`SWT8U$"?]0Z+WB__^)1"04@\00BWPD
M!(V3YYO__X`^`'0=40^V!D904HE4)!17@\<"Z+OC__^#Q!"+5"0(Z]Z-?"1$
MBS>%]G0IB?#HX?/__X7`B<9T(H`X`'0=Z'SW__^%P'04@^P,5NB,XO__@\00
MB<:-?"0LZS2#QP3KQHL7A=)T+8`Z`'0HB=")5"0(Z$GW__^%P(M4)`AT#H/L
M#%+H5>+__X/$$(G&@\<$A?9TS3'`@\G_B??RKHM\)`2#[`SWT8G*@\G_\JZ)
MR/?0C;P"`@0``%?H[^'__XE$)!A8C8/LF___6O]T)`Q0C8,&F___B40D'%"-
M@_&;__]64/]T)"3HZN+__X/$&&C``0``_W0D%.BIXO__@\000'4WZ);B__^#
M.!%T+>B,XO__@^P,_S"-@_J;____="08_W4`4(N#&````/\PZ"SB__^#Q"#I
M*`<``(NSE````(/L#/\VZ(3B__]:604H`0``4/]T)!3H<^'__XE$)""#Q!"#
M?"00``^%UP8``(/L#/\VZ%?B__^+@#@!``"#Q!`E`/```#T`0```#X6T!@``
M@^P,_S;H-.+__XN`0`$``(E$)!3H5>+__X/$$#E$)`0/A8X&``"#[`S_-N@.
MXO__BX`X`0``@\00)?\!```]P`$```^%:P8``(/L#%?HS.#__XE$)!2-@\B;
M___H)?+__X/$$(7`#X1``0``@^P,4.C9X/__6EE0_W4`Z+WW__^#Q!"%P(G&
M#X0?`0``,<"#R?^)]_*N]]&->?^#_P,/CQ`!``#HEOO__X7`B40D%`^%;P4`
M`%=7:@!6Z)?@__^#Q!"%P(G&#X18!0``:@)J_VKN4.C^W___@\0,:@:-O"0$
M`0``5U;H`^'__X/$$("\)/P`````#X4M`0``@+PD_0```$,/A1\!``"`O"3^
M````00^%$0$``("\)/\```!##X4#`0``@+PD``$``$@/A?4```"`O"0!`0``
M10^%YP```&H":O]JQE;HB-___X/$#&HI5U;HE.#__XV#5IW__UE>4%?_="0<
MC8,_G/___W0D'%#_="0@Z,K@__^#Q""#[`S_="04Z)/@__^+5"04C8/NFO__
MZ('Q__]8_W0D$.@5^___@\00Z2X%``"+=0#IV?[__U!0C8,UG/__4(U$#OM0
MZ!_?__^#Q!"%P`^%TO[__X/_!'0+@'P^^R\/A<+^__^+;02%[0^$M_[__S'`
M@\G_B>_RKO?1C4'_@_@##X:@_O__4%"-@SJ<__]0C40-^U#HS][__X/$$(7`
M#X6"_O__B>[I>_[__VH`:@!J`%;HH=[__\=$)&P!(T5GQT0D<(FKS>_'1"1T
M_MRZF,=$)'AV5#(0QT0D?/#ATL/'A"2``````````,>$)(0`````````QX0D
MR`````````"#Q!"-A"3\````B40D$(U$)'B)1"0,5V@`@```_W0D&%;H2M__
M_X/$$(7`B<</CD4!``"-!/T``````T0D<',$_T0D=(E$)'")^,'H'0%$)'2+
MA"2X````A<!T=;E`````B?TIP3G/?@*)S0-$)`P[1"00<PF-#"@Y3"00<A`[
M1"00=@R+3"00`>DYR',"#PN!_0"```!W]E)5_W0D&%#H+-___XN$),@````!
MZ(F$),@```"#Q!"#^$`/A5;___^-1"1<*>\#;"00Z,OB___K!XVL)/P```"-
MA"2X````B40D'(/_/WY$.VPD#'8&.VPD''*:.VPD#',)C45`.40D#'*+4&I`
M@^]`58/%0(U$)&B)1"0D_W0D&.BRWO__BT0D*.ASXO__@\00Z[<[;"0,=@Z+
M1"0,`?@YQ0^"3O___SML)`QS#HU$/0`Y1"0,#X(Z____@_]$#X<Q____4%=5
M_W0D&.AGWO__B;PDR````(/$$.F>_O__@^P,5NC?W?__BZPD@````(NT)(0`
M``")ZL'J`X/B/XU"`<:$%(@```"`@\00@_@X?C6Z0````%$IPE)J`(V\)(0`
M``"-3"1H`?B)3"084.B\W/__BT0D'.C%X?__@\0,:CAJ`%?K$U*Z.````"G"
M4FH`C80$A````%#HD=S__XGP@\00P>@8B(0DL````(GPP>@0B(0DL0```(GP
MP>@(B(0DL@```(GPC;0DTP```(B$)+,```")Z,'H&(GWB(0DM````(GHP>@0
MB(0DM0```(GHP>@(B(0DM@```(GHC:OGF___B(0DMP```(U$)%SH+N'__XM$
M)%R)PHB$),(```#!ZAB(E"2_````B<+!ZA"(E"3`````B<*+1"1@P>H(B)0D
MP0```(G"B(0DQ@```,'J&(B4),,```")PL'J$(B4),0```")PHM$)&3!Z@B(
ME"3%````B<*(A"3*````P>H8B)0DQP```(G"P>H0B)0DR````(G"BT0D:,'J
M"(B4),D```")PHB$),X```#!ZAB(E"3+````B<+!ZA"(E"3,````B<*+1"1L
MP>H(B)0DS0```(G"B(0DT@```,'J&(B4),\```")PL'J$(B4)-````")PL'J
M"(B4)-$```"-E"2_````4(M$)!B)5"00#[8$$%!55H/&`NA2W/___T0D)(/$
M$(-\)!04BU0D#'76C8-6G?__QH0D^P````!555"-@P:;__]74.E$^___C9/S
MG/__C8-%F___C;M<G/__Z.#L___HGMK__U96C;-6G?__5E"-@TZ<____="0<
M_W0D'%#_="0@Z.3;__^#Q"!24FC``0``_W0D$.BAV___@\000`^%`/O__^B*
MV___@S@1#X7R^O___T0D$.A(VO__45;_="084/]T)!S_="0<5_]T)"#HE]O_
M_X/$(.NQC8-MG/___W0D"/]U`%"+@Q@```#_,.C_VO__@\00QT0D!`````"+
MC"3\@```93,-%````(M$)`1T!>AK`P``@<0,@0``6UY?7<-55U93Z);=__^!
MP_]H``"#["B+LY0```#_-N@AV___7?\VB<?H%]O__XI`9(A'98V#*9O__^A.
MZ___@\00A<!T"X`X,74&@'@!`'0%Z)+S__^#[`S_-NCEVO__C9/,G/__:@MJ
M`5)0Z`3:__^#Q""%P'4M@^P,_S;HP]K__XV3T9S__VH#:@%24.CBV?__@\0@
MA<")QP^%S@```.D-`0``BT`,OP$```"+:!@[NZ`1``"-1_^)1"0(?1Z#[`S_
M-NA\VO__:@#_="0<55#H+]G__X/$((7`=1B+@Z`1``"_`0```(E$)`Q(.40D
M"'6%ZU2+$(M"""4`!"``/0`$``!U!8M"#.L@B50D#(/L#/\VZ"S:__]J`FH`
MBU0D)%)0Z#W:__^#Q"!145"+@YP1``#_-+CHL=C__X/$$(7`=9I'Z6?___\[
MNZ`1```/C2/___^#[`S_-D?HY=G__UE:55#H--C__X/$$.O;BT`,@^P,BRC_
M-NC(V?__C9/3G/__@\0,4E50Z/_8__^+1PR#Q!"+./9'"D!T%H/L#/\VZ)_9
M__]=6E=0Z&;8__^#Q!"#[`S_-NB)V?__C9/8G/__:@-J`5)0Z*C8__^#Q""%
MP(G%=&>-@_>:___HK.G__X7`B<=T!8M%#.LWZ&GN__^%P(G'BT4,="&#[`R+
M*/\VZ#_9__^#Q`Q755#H?-C__XD\).@,V?__ZQ^+DYP1``"+.HLH@^P,_S;H
M%MG__X/$#%=54.A3V/__@\00@^P,_S;H_MC__XV3VIS__X/$#&H!4E#H7-?_
M_UK_-HG'Z.+8__^-D^^<__^#Q`Q25U#H&=C__UG_-NC)V/__QD!E`(V#[IK_
M_^@"Z?__@\00A<")@Z01``!U)H/L#/^SG!$``.C#\___@\00A<")@Z01``!U
M"X/L#(V#]9S__^LW4%!HP`$``/^SI!$``.A-V/__C5`!@\00@_H!=B"#^!%T
M&U"+@YP1``#_LZ01``#_,(V#%IW__U#HVM;__X/$'%M>7UW#5U93BW0D$.B5
MVO__@</^90``@^P,5N@9\/__B00DZ/CO__^#Q!")Q^@6\O__A<!T*87V="6`
M/@!T(%!0C8/LF___4%?H&=?__X/$$#G'=0I;B?!>7^EZZO__6UY?PXL4),-3
MZ#G:__^!PZ)E``"#[`CH]-?__X/$"%O#5>B3V___!8EE``")Y5-2C9@X____
M@^L$BP.#^/]T!/_0Z_)86UW#@^P,Z'?:__^#Q`S#+BX`)7,O)7,`1'EN84QO
M861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`&5X
M90`O<')O8R\E:2\E<P!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU
M3$E"`%!%4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!0
M05)?4U!!5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?
M1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%2
M7T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0!,1%],
M24)205)97U!!5$@`4UE35$5-`"]T;7``55-%4@!54T523D%-10`E,#)X`'!A
M<BT`)7,E<R5S)7,`)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T
M;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@!P87)L`"YP87(`)7,E<V-A8VAE
M+25S)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`"5S.B!P<FEV
M871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@
M:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H`5$5-4$1)4@!435``05)'
M5@`8`'!E<FP`,`!005(Z.E!A8VME<CHZ5D524TE/3@`Q+C`T,0!5;F%B;&4@
M=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*
M`"UE`"TM`&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D
M0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C
M:V%G92!?7W!A<E]P;#L*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP
M9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&
M:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I
M;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M
M92@D<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R
M7W1E;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@
M/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E
M;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM
M>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A8
M6"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*
M4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@
M(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M
M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N
M"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B
M("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I
M;&5N86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU
M;&P@,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q
M*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU
M<#H@*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA
M;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"
M3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.
M5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H
M)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@
M*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G
M*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG
M(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D[
M"FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]7
M05).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@
M;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1P
M<F]G;F%M93L*;7D@)&]F9G-E="`](#4Q,CL*;7D@)&ED>"`]("TQ.PIW:&EL
M92`H,2D*>PHD;V9F<V5T(#T@)'-I>F4@:68@)&]F9G-E="`^("1S:7IE.PIS
M965K(%]&2"P@+21O9F9S970L(#(@;W(@9&EE('%Q6W-E96L@9F%I;&5D(&]N
M("(D<')O9VYA;64B.B`D(5T["FUY("1N<F5A9"`](')E860@7T9(+"`D8G5F
M+"`D;V9F<V5T.PID:64@<7%;<F5A9"!F86EL960@;VX@(B1P<F]G;F%M92(Z
M("0A72!U;FQE<W,@)&YR96%D(#T]("1O9F9S970["B1I9'@@/2!R:6YD97@H
M)&)U9BP@(EQN4$%2+G!M7&XB*3L*;&%S="!I9B`D:61X(#X](#`@?'P@)&]F
M9G-E="`]/2`D<VEZ92!\?"`D;V9F<V5T(#X@,3(X("H@,3`R-#L*)&]F9G-E
M="`J/2`R.PI]"FQA<W0@=6YL97-S("1I9'@@/CT@,#L*)&]F9G-E="`M/2`D
M:61X("T@-#L*<V5E:R!?1D@L("TD;V9F<V5T+"`R.PIR96%D(%]&2"P@)&)U
M9BP@-#L*<V5E:R!?1D@L("TD;V9F<V5T("T@=6YP86-K*").(BP@)&)U9BDL
M(#(["G)E860@7T9(+"`D8G5F+"`T.PHD9&%T85]P;W,@/2`H=&5L;"!?1D@I
M("T@-#L*;7D@)7)E<75I<F5?;&ES=#L*=VAI;&4@*"1B=68@97$@(D9)3$4B
M*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K
M*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7$H56YP
M86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]("@@)&9U
M;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*
M;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ
M*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L
M('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X
M="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@
M7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I
M9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.
M5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&)A
M<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N
M86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*
M)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]
M/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["GT*
M<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H
M)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O
M<B`A)&UO9'5L93L*;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI
M<W1[)&UO9'5L97T@?'P@9&\@>PIM>2`D:V5Y.PIF;W)E86-H("AK97ES("5R
M97%U:7)E7VQI<W0I('L*;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B1K
M97D@/2`D7SL@;&%S=#L*?0ID96QE=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I
M9B!D969I;F5D*"1K97DI.PI](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]
M("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,
M14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@
M24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I
M.PIP<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*<V5E:R@D9F@L(#`L(#`I
M.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I
M;&4H(B1F:6QE;F%M92T^>V-R8WTN<&TB+"`D9FEL96YA;64M/GMB=69]*3L*
M;W!E;B!M>2`D9F@L("<\)RP@)&9I;&5N86UE(&]R(&1I92`B8V%N)W0@<F5A
M9"`D9FEL96YA;64Z("0A(CL*8FEN;6]D92@D9F@I.PIR971U<FX@)&9H.PI]
M"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U
M;&4A7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!0
M05(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R
M=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR
M97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@
M:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N
M86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M
M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@
M>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O
M;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M
M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R
M=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0IM>2!`<&%R7V%R9W,["FUY("@D
M;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%
M3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A
M('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%2
M7T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP
M87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP
M("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?
M<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@
M86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.
M5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO
M<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!
M4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO
M(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@
M)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L
M<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L
M<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G
M8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2![
M"B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE
M="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^
M(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B.PI]"F5L
M<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`
M05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@
M)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I
M<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)0
M05(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS
M:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q
M=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'!A
M<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@
M>PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@Q,C@J,3`R-"D["F]P96X@
M;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z
M("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD
M>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE
M2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*
M;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D
M;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-
M151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]
M?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG
M.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E
M;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A0
M05(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2
M/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F
M:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@
M?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL
M"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN
M960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L
M(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@
M>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*?0IF;W)E86-H
M(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K
M97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG
M(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?
M7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L
M;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@
M>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R
M:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U
M:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H
M*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G
M<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@
M;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@
M;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E
M9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E
M9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG
M.CI#;VYF:6=[;&EB7V5X='T["FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T
M(&ME>7,@)69I;&5S*2!["FUY("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY
M("1D:7(@*$!I;F,I('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD7WTI('L*)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D
M9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q
M+"`D,BD["FQA<W0["GT*96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#
M8UTI7%HA*2!["FEF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A
M8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0[
M"GT*96QS:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B
M)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE
M9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R
M968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T
M<R@@:F]I;B`B(BP*<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M
M/GMN86UE?2`Z("1F:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@
M*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS
M92!["F]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@
M)&9I;&4Z("0A(CL*8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X[
M"F-L;W-E($9)3$4["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L
M>2A<)&-O;G1E;G0L("1F:6QE*0II9B`A)$5.5GM005)?5D520D%424U](&%N
M9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0
M871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA
M;64I.PI]"F]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B1F:"T^<')I
M;G0H(D9)3$4B*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE
M*2`K(#DI*3L*)&9H+3YP<FEN="AS<')I;G1F*`HB)3`X>"\E<R(L($%R8VAI
M=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64**2D["B1F
M:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*)&9H+3YP
M<FEN="@D8V]N=&5N="D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D
M9F@I(&EF("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE
M+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T
M870H)&]U="DI6SE=*2!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U
M:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM
M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].
M('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V
M97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@
M:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L
M("(\)&]U="(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I
M.PIC;&]S92@D9F@I.PI]"GT*)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^
M:&5X9&EG97-T(#H@)&UT:6UE.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H
M-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#
M2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K
M*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I
M;G0H(EQN4$%2+G!M7&XB*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U
M=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*
M7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER
M92!!<F-H:79E.CI::7`["GT*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W
M.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PHD9F@M/F9D;W!E;BAF:6QE;F\H
M7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B1Z:7`M/G)E861&<F]M1FEL
M94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I(&]R(&1I92`B)"$Z("1`(CL*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II
M<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]
M("$D14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@
M(B1%3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0
M?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M
M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R
M+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL
M94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL
M:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG
M.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A
M8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T
M9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D
M9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ
M92@I*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@
M:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@96QS92![
M"F]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?
M;F%M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA
M;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B
M.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@
M>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N
M<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R
M;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN
M"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H
M0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR
M97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@
M)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN
M+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H
M*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@
M97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E
M<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T
M<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E
M($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U
M:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ
M4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I
M<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP
M<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@4$%2
M.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E
M<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R
M97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@
M<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV
M93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ
M3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER
M92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*
M<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0
M?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]
M("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD
M7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI
M+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN
M960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N
M86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI
M(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.
M86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS
M:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE
M;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52
M?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S
M=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(
M*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%
M3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE
M*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["G-E96L@
M)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PII9B`H)&)U
M9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@,CL*<WES<F5A9"`D
M9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D
M0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*?0IE;'-E('L*;7D@)&-T
M>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^
M;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E
M<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U
M.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@
M>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S
M:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C
M='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E
M('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2![
M"F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I
M.PI]"GT*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H
M("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*?0IC;&]S92@D
M9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N
M/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@
M/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A
M<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%
M35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F:6QE('L*;7D@*"1N86UE+"`D
M8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T
M96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N
M86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@;7D@)&9H+"`G/B<L("1T96UP
M;F%M92!O<B!D:64@(F-A;B=T('=R:71E("1T96UP;F%M93H@)"$B.PIB:6YM
M;V1E("1F:#L*<')I;G0@)&9H("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO
M9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D
M=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*
M<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD
M969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!
M345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@
M?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M
M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R
M*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]
M*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P
M<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY
M("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II
M9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N
M/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@
M*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2![
M"FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%
M3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O
M+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P
M<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-
M17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P
M*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*
M?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T
M8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E
M=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O
M7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E
M;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@
M7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@
M/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%
M1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#
M04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PID96QE=&4@)$5.5GLG
M4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'
M("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1?
M?2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R
M7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*
M:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT[
M"GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM
M>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,
M14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY0
M05)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U
M:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS
M92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@
M0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z
M.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R
M8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI
M.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@
M7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@
M<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B
M.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O
M9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^
M+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?
M7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?
M15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/
M4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@````!?7T5.5E]005)?0TQ%
M04Y?7R`@("`@("`@("`@("`@(`````!P97)L>'-I+F,````!&P,[V````!H`
M``"TEO__]````,26__\8`0``K)C__Q@-``!.G/__+`$``"RH__]L`0``O*C_
M_[@!``#KJ/__T`$``%&I__\$`@``!JO__W0"``!GK/__/`,``/NL__^@`P``
M-JW__]`#``")K?__'`0``&ZN__^H!```<Z[__[P$``!-L/__N`4``&:P___,
M!0``%['__R@&``!ULO__;`8``,"R__^,!@``[[+__[@&``"8L___.`<``#2]
M__]`"P``,L#__\0,``"0P/__7`T``)3`__]P#0``%``````````!>E(``7P(
M`1L,!`2(`0``(````!P```"XE?__$``````."$8.#$H/"W0$>``_&CLJ,B0B
M$````$````"DE?__Z`$````````\````5````!J;___>"P```$$."(4"00X,
MAP-##A"&!$$.%(,%1@Z0`P/-"PX40<,.$$'&#@Q!QPX(0<4.!```2````)0`
M``"XIO__D`````!!#@B%`D$.#(<#00X0A@1!#A2#!5`.,'T.-$$..$$./$4.
M0$@.,&D.%$/##A!!Q@X,0<<."$'%#@0``!0```#@````_*;__R\`````0PX@
M:PX$`#````#X````$Z?__V8`````00X(AP)!#@R&`TP.$(,$10X@`D\.$$'#
M#@Q!Q@X(0<<.!`!L````+`$``$6G__^U`0```$$."(4"00X,AP-!#A"&!$$.
M%(,%0PY``J<.1$$.2$$.3$$.4$X.0%@.3$$.4%(.0$H.1$$.2$4.3$$.4$X.
M0'0.3%(.4$@.0`)9#A1!PPX00<8.#$''#@A!Q0X$````Q````)P!``"*J/__
M80$```!!#@B%`D$.#(<#00X0A@1!#A2#!48.H`%N#JP!00ZP`4@.H`%A#JP!
M00ZP`4@.H`%/#J0!00ZH`40.K`%$#K`!2`Z@`44.I`%!#J@!1`ZL`40.L`%(
M#J`!4`ZL`5P.L`%1#K0!00ZX`4$.O`%!#L`!2`ZH`44.K`%!#K`!2`Z@`5\.
MK`%!#K`!2`Z@`4,.K`%!#K`!2`Z@`4@.K`%!#K`!4`Z@`5@.%$'##A!!Q@X,
M0<<."$'%#@1@````9`(``".I__^4`````$$."(<"00X,A@-##A"#!$X.'$@.
M($8.'$$.&$8.'$$.($@.$$L.'$(.($X.$$T.%$$.&$(.'$$.($@.$$T.'$(.
M($X.$$_##@Q!Q@X(0<<.!```+````,@"``!3J?__.P````!!#@B#`DX.'$@.
M($P.)$P.*$$.+$$.,$@."$'##@0`2````/@"``!>J?__4P````!!#@B&`D$.
M#(,#3@X<2`X@3@X<0@X@1@X<1PX80@X<00X@00XD1PXH1PXL00XP2`X,0<,.
M"$'&#@0``(@```!$`P``9:G__^4`````00X(A0)!#@R'`T$.$(8$00X4@P51
M#K!`70Z\0$$.P$!!#L1`1P[(0$4.S$!%#M!`2PZP0%,.M$!%#KA`2`Z\0$$.
MP$!(#K!`3`Z\0$$.P$!(#K!`9@ZT0$$.N$!!#KQ`00[`0$P.L$!=#A1!PPX0
M0<8.#$''#@A!Q0X$$````-`#``"^J?__!0````````#X````Y`,``*^I___:
M`0```$$."(4"00X,AP-!#A"&!$$.%(,%1@[`('H.Q"!!#L@@0@[,($$.T"!(
M#L`@;`[$($$.R"!'#LP@00[0(%`.P"!?#L0@00[(($$.S"!%#M`@2`[`(`)`
M#L0@00[(($$.S"!!#M`@1P[4($$.V"!%#MP@10[@($D.P"!,#LP@1@[0($8.
MS"!!#L@@1@[,($$.T"!(#L`@1P[,($8.T"!.#L`@30[$($$.R"!"#LP@00[0
M($@.P"!4#LP@00[0($@.P"!%#L0@00[(($<.S"!"#M`@2`[`(&0.%$'##A!!
MQ@X,0<<."$'%#@0````0````X`0``(VJ__\9`````````%@```#T!```DJK_
M_[$`````00X(A0)!#@R'`T$.$(8$00X4@P5##B`"30H.+$@+20XL00XP2`X@
M9`XD00XH00XL1PXP2`X@20X40<,.$$'&#@Q!QPX(0<4.!```0````%`%``#G
MJO__7@$```!!#@B'`D$.#(8#00X0@P1##D`#"0$.1$@.2$$.3$$.4$@.0'D.
M$$'##@Q!Q@X(0<<.!``<````E`4```&L__]+`````$$."(,"3@X0>@X(0<,.
M!"@```"T!0``+*S__R\`````00X(@P).#A!(#AQ!#B!(#A!+#@A#PPX$````
M?````.`%```OK/__J0````!!#@B%`D$.#(<#00X0A@1!#A2#!4,.,'$*#A1"
M"T$.-$$..$$./$$.0$@.,$P./%P.0%$.1$<.2$$.3$$.4%`.%$'##A!!Q@X,
M0<<."$'%#@1%#C"#!84"A@2'`T,.%$'##A!!Q@X,0<<."$'%#@0$!```8`8`
M`%BL__^<"0```$$."(4"00X,AP-!#A"&!$$.%(,%1@Z@@@("A`H.K(("00ZP
M@@)6"V@.K(("00ZP@@)(#J""`ET.K(("1PZP@@),#J""`E`.I(("10ZH@@)!
M#JR"`D4.L(("2PZ@@@)N#JR"`D$.L(("2`Z@@@)N#JR"`D$.L(("2`Z@@@)9
M#JR"`E4.L(("2@ZL@@)'#JB"`D0.K(("00ZP@@)+#K2"`D<.N(("00Z\@@)$
M#L""`D@.J(("10ZL@@)$#K""`D@.H(("50ZL@@)"#K""`DH.M(("0PZX@@)!
M#KR"`D@.P(("2`Z@@@).#JR"`D(.L(("1@ZL@@)!#JB"`D8.K(("1`ZP@@),
M#J""`DX.K(("0@ZP@@).#J""`E,.K(("0@ZP@@)7#J""`DT.K(("0@ZP@@).
M#J""`E,.K(("00ZP@@)7#J""`DL.K(("00ZP@@)&#JR"`D$.J(("00ZL@@)#
M#K""`D@.H(("<PZD@@)!#JB"`D(.K(("00ZP@@)(#J""`DP.I(("0@ZH@@)"
M#JR"`D$.L(("2`ZD@@)"#JB"`D@.K(("00ZP@@)(#J""`@)6#J2"`D(.J(("
M0@ZL@@)!#K""`D@.I(("0@ZH@@)!#JR"`D$.L(("3`ZL@@)!#JB"`D$.K(("
M00ZP@@)$#K2"`DH.N(("00Z\@@)$#L""`D@.H(("0PZL@@)$#K""`E4.K(("
M1`ZP@@)(#J""`DX.I(("00ZH@@)'#JR"`D4.L(("2`Z@@@)[#J2"`D$.J(("
M1PZL@@)%#K""`D@.H(("40ZD@@)"#JB"`D(.K(("00ZP@@("40Z@@@)4#J2"
M`D4.J(("1`ZL@@)!#K""`D@.H(("`G`.I(("00ZH@@)$#JR"`D$.L(("6`Z@
M@@("30ZD@@)"#JB"`D0.K(("3PZP@@)1#J""`G0.I(("00ZH@@)!#JR"`D0.
ML(("3PZ@@@)("@ZL@@)!#K""`FD.H(("2PZD@@)##JB"`D(.K(("4@ZP@@)1
M#J2"`D(.J(("0@ZL@@)!#K""`D(+00ZD@@)(#JB"`D(.K(("2`ZP@@)*#J""
M`@-C`0H.I(("30ZH@@)!#JR"`D$.L(("3PZ@@@):#J2"`D$.J(("00ZL@@)'
M#K""`D$.M(("10M=#J2"`D$.J(("1PZL@@)!#K""`DH.M(("1`ZX@@)!#KR"
M`D0.P(("2`Z@@@)!#J2"`D$.J(("10ZL@@)$#K""`D@.H(("7PZD@@)!#JB"
M`D0.K(("00ZP@@)$#K2"`D0.N(("00Z\@@)$#L""`D@.H(("3`ZD@@)##JB"
M`D$.K(("2`ZP@@)(#J""`F<.%$'##A!!Q@X,0<<."$'%#@2``0``:`H``.RQ
M___^`@```$$."(4"00X,AP-!#A"&!$$.%(,%3@X\2`Y`1@X\0@Y`6PXP5PX\
M0@Y`30Y$0@Y(00Y,00Y02`XP1PX\0@Y`30Y$0@Y(00Y,00Y02`XP;`X\0@Y`
M1PY$1`Y(00Y,00Y02`XP>0X\0@Y`1PY$0@Y(10Y,00Y02`XP00XT00XX00X\
M20Y`2`XP60X\0@Y`1PX\00XX00X\00Y`2`XP2`X\1`Y`3@XT00XX00X\00Y`
M2PXP2PX\0@Y`1@X\00XX00X\00Y`2`XP0PX\0@Y`30Y$0@Y(00Y,00Y02`XP
M;0H./$0.0$@.-$$..$$./$$.0$\+30X\0@Y`2`XT00XX00X\00Y`2`XP0PH.
M/$(.0$X.-$(..$$./$$.0$8./$(.0%`.-$$..$$./$$.0$8./$(.0%<.,$T.
M/$8.0$@.,$T./$@+00XT00XX10X\1@Y`2PXP2PXT3`XX0@X\1PY`10XP0PX4
M0<,.$$'&#@Q!QPX(0<4.!```4````.P+``!FL___7@````!!#@B'`D$.#(8#
M00X0@P12#AQ!#B!0#A!5#A1!#AA'#AQ!#B!(#A!%"L,.#$/&#@A!QPX$10M!
MPPX,0<8."$''#@0`0````$`,``",B___V@$```!$#`$`2A`%`G4`1@\#=7`&
M$`<"=7P0!@)U>!`#`G5T`[X!P0P!`$'#0<9!QT'%0PP$!``0````A`P``"RS
M__\$`````````!P```"8#```'+/__QD`````00X(@P).#A!(#@A!PPX$````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````_____P````#_____
M```````````!`````0````$```#7`@``#P```'0#```,````+`\```T```!@
M.0``]?[_;TP!```%````*`@```8````(`@``"@```'$$```+````$````!4`
M`````````P```,B>```1````G`P``!(```"0`@``$P````@````8````````
M`/O__V\!```(^O__;PH`````````````````````````````````````````
M````````````````$)X````````````````````````X$0``````````````
M`````````````````````````&`Y````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+`\`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````*```$XZ``!'.@``B#L``&0Z``"0.P```````/____\E/```
M1T-#.B`H06QP:6YE(#8N-"XP*2`V+C0N,```+G-H<W1R=&%B`"YI;G1E<G``
M+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N<F5L+F1Y;@`N:6YI=``N<&QT
M`"YP;'0N9V]T`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N
M96A?9G)A;64`+F-T;W)S`"YD=&]R<P`N:F-R`"YD>6YA;6EC`"YD871A`"YB
M<W,`+F-O;6UE;G0`````````````````````````````````````````````
M``````````L````!`````@```#0!```T`0``%P```````````````0``````
M```3````]O__;P(```!,`0``3`$``+P````#``````````0````$````'0``
M``L````"````"`(```@"```@!@``!`````$````$````$````"4````#````
M`@```"@(```H"```<00``````````````0`````````M````"0````(```"<
M#```G`P``)`"```#``````````0````(````-@````$````&````+`\``"P/
M```1```````````````!`````````#P````!````!@```$`/``!`#P``$```
M````````````$`````0```!!`````0````8```!0#P``4`\``.@!````````
M``````@`````````2@````$````&````.!$``#@1```H*``````````````!
M`````````%`````!````!@```&`Y``!@.0``#````````````````0``````
M``!6`````0````(```!L.0``;#D``!X_``````````````0`````````7@``
M``$````"````C'@``(QX``#<```````````````$`````````&P````!````
M`@```&AY``!H>0``N`P`````````````!`````````!V`````0````,```#\
MG0``_(T```@```````````````0`````````?0````$````#````!)X```2.
M```(```````````````$`````````(0````!`````P````R>```,C@``!```
M````````````!`````````")````!@````,````0G@``$(X``+@````$````
M``````0````(````10````$````#````R)X``,B.```X`0`````````````$
M````!````)(````!`````P````"@````D```)```````````````!```````
M``"8````"`````,```!`H```))```#00`````````````"``````````G0``
M``$````P`````````"20```:```````````````!`````0````$````#````
@```````````^D```I@```````````````0``````````
